#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-env
version:              0.1.1
visibility:           public
id:                   th-env-0.1.1-4RFhnaHLi5r63Q0u1KyIQw
key:                  th-env-0.1.1-4RFhnaHLi5r63Q0u1KyIQw
license:              BSD-3-Clause
maintainer:           dima@dzhus.org
author:               Dmitry Dzhus
homepage:             https://github.com/dzhus/th-env#readme
synopsis:
    Template Haskell splices that expand to an environment variable

description:
    TH splices that expand to an environment variable value. Can be used to embed build-time parameters in your application.

category:             Template Haskell
abi:                  dc85ee6983a13a60c594240d4f665bbc
exposed:              True
exposed-modules:      Language.Haskell.TH.Env
hidden-modules:       Paths_th_env
import-dirs:          /usr/lib/ghc-9.6.6/site-local/th-env-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/th-env-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/th-env-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-env
hs-libraries:         HSth-env-0.1.1-4RFhnaHLi5r63Q0u1KyIQw
depends:
    base-4.18.2.1 template-haskell-2.20.0.0
    th-compat-0.1.7-IFFeqpuLlRrB57TfAeBVRb

haddock-interfaces:   /usr/share/doc/haskell-th-env/html/th-env.haddock
haddock-html:         /usr/share/doc/haskell-th-env/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

